@@ -1,16 +1,20 @@
 import { eachTest } from 'postcss-parser-tests'
+import { test } from 'uvu'
+import { is } from 'uvu/assert'
 
 import { stringify, parse } from '../lib/postcss.js'
 
 eachTest((name, css) => {
   if (name === 'bom.css') return
 
-  it(`stringifies ${name}`, () => {
+  test(`stringifies ${name}`, () => {
     let root = parse(css)
     let result = ''
     stringify(root, i => {
       result += i
     })
-    expect(result).toEqual(css)
+    is(result, css)
   })
 })
+
+test.run()
